@@ -36,13 +36,20 @@ organization = "Yubico"
 domain = "yubico.com"
 app_name = "YubiKey NEO Manager"
 win_title_1 = "YubiKey NEO Manager (%s)"
+ok = "OK"
+cancel = "Cancel"
 wait = "Please wait..."
+welcome = "Welcome"
+note_1 = "NOTE: %s"
 overview = "Overview"
-hid = "HID"
+otp = "OTP"
 ccid = "CCID"
-hid_ccid = "HID+CCID"
+otp_ccid = "OTP+CCID"
+u2f = "U2F"
+otp_u2f = "OTP+U2F"
+u2f_ccid = "U2F+CCID"
+otp_u2f_ccid = "OTP+U2F+CCID"
 ccid_touch_eject = "CCID with touch eject"
-hid_ccid_touch_eject = "HID+CCID with touch eject"
 requires_ccid = "Requires CCID mode"
 settings = "Settings"
 installed_apps = "Installed apps"
@@ -57,12 +64,18 @@ change_mode_desc = ("Set the connection mode used by your YubiKey NEO.\nFor "
                     "this setting to take effect, you will need to unplug, "
                     "and re-attach your YubiKey.")
 remove_device = "\nRemove your YubiKey NEO now.\n"
+mode_note = ("To be able to list/manage apps, your YubiKey NEO must have CCID "
+             "enabled.")
 name = "Name"
 name_1 = "Name: %s"
 serial_1 = "Serial: %s"
 firmware_1 = "Firmware version: %s"
+u2f_1 = "U2F/FIDO: %s"
+u2f_supported = "supported"
+u2f_not_supported_1 = "<a href=\"%s\">not supported</a>"
 aid_1 = "AID: %s"
 status_1 = "Status: %s"
+version_1 = "Version: %s"
 latest_version_1 = "Latest version: %s"
 download = "Download"
 downloading_file = "Downloading file..."
@@ -88,8 +101,13 @@ install_cap = "Install applet from CAP file"
 select_cap = "Select a CAP file"
 devices = "Devices"
 apps = "Available apps"
+installed_apps = "Installed apps"
 unknown = "Unknown"
 unknown_applet = "Unknown applet"
+about_1 = "About: %s"
+libraries = "Library versions"
+about_link_1 = "For help and discussion, see our <a href=\"%s\">forum</a>."
+copyright = "Copyright &copy; 2014 Yubico"
 
 
 def _translate(qt):
